@@ -4,7 +4,9 @@
 //= require jquery.timeago
 
 (function($) {
-	$(document).on('ready page:load', function() {
+	var fn = function() {
 		$('time[data-time-ago]').timeago();
-	});
+	};
+	$(fn);
+	$(document).on('turbolinks:load page:load ajax:success', fn);
 })(jQuery);
