@@ -1,19 +1,21 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 RSpec.describe Rails::Timeago::Helper do
   before { @stub = TimeagoStub.new }
   let(:time) { Time.now }
 
-  context "#timeago_tag" do
+  context '#timeago_tag' do
     let(:kwargs) { {} }
     subject { @stub.timeago_tag(time, **kwargs) }
 
     it 'creates a time tag' do
-      is_expected.to match /<time.*>.*<\/time>/
+      is_expected.to match %r{<time.*>.*</time>}
     end
 
     it 'has a title attribute' do
-      is_expected.to match /<time.*title=".*".*>.*<\/time>/
+      is_expected.to match %r{<time.*title=".*".*>.*</time>}
     end
 
     it 'has a human readable datetime as title attribute' do
@@ -21,7 +23,7 @@ RSpec.describe Rails::Timeago::Helper do
     end
 
     it 'has a data-time-ago attribute' do
-      is_expected.to match /<time.*data-time-ago=".*".*>.*<\/time>/
+      is_expected.to match %r{<time.*data-time-ago=".*".*>.*</time>}
     end
 
     context 'with nil as timestamp' do
@@ -40,7 +42,7 @@ RSpec.describe Rails::Timeago::Helper do
       end
 
       context 'with proc format' do
-        let(:format) { proc {|time, options| :long } }
+        let(:format) { proc {|_time, _options| :long } }
         it { is_expected.to include "title=\"#{I18n.l time, format: :long}\"" }
       end
     end
@@ -54,7 +56,7 @@ RSpec.describe Rails::Timeago::Helper do
       end
 
       context 'with proc format' do
-        let(:format) { proc {|time, options| :long } }
+        let(:format) { proc {|_time, _options| :long } }
         it { is_expected.to include "title=\"#{I18n.l time, format: :long}\"" }
       end
     end
@@ -64,18 +66,18 @@ RSpec.describe Rails::Timeago::Helper do
 
       context 'with title disable' do
         let(:title) { false }
-        it { is_expected.to_not match /<time.*title=".*".*>.*<\/time>/ }
+        it { is_expected.to_not match %r{<time.*title=".*".*>.*</time>} }
       end
 
       context 'with title set to nil' do
         let(:title) { nil }
-        it { is_expected.to_not match /<time.*title=".*".*>.*<\/time>/ }
+        it { is_expected.to_not match %r{<time.*title=".*".*>.*</time>} }
       end
 
       context 'with title set to proc' do
         let(:title) { proc {|_, o| o[:format] } }
         let(:kwargs) { super().merge format: :short }
-        it { is_expected.to match /<time.*title="short".*>.*<\/time>/ }
+        it { is_expected.to match %r{<time.*title="short".*>.*</time>} }
       end
     end
 
@@ -84,18 +86,18 @@ RSpec.describe Rails::Timeago::Helper do
 
       context 'with title disabled' do
         let(:title) { false }
-        it { is_expected.to_not match /<time.*title=".*".*>.*<\/time>/ }
+        it { is_expected.to_not match %r{<time.*title=".*".*>.*</time>} }
       end
 
       context 'with title set to nil' do
         let(:title) { nil }
-        it { is_expected.to_not match /<time.*title=".*".*>.*<\/time>/ }
+        it { is_expected.to_not match %r{<time.*title=".*".*>.*</time>} }
       end
 
       context 'with title set to proc' do
         let(:title) { proc {|_, o| o[:format] } }
         let(:kwargs) { {format: :short} }
-        it { is_expected.to match /<time.*title="short".*>.*<\/time>/ }
+        it { is_expected.to match %r{<time.*title="short".*>.*</time>} }
       end
     end
 
@@ -103,7 +105,7 @@ RSpec.describe Rails::Timeago::Helper do
       let(:time) { 5.days.ago }
 
       it 'should not have data-time-ago attribute for times before limit' do
-        is_expected.to_not match /<time.*data-time-ago=".*".*>.*<\/time>/
+        is_expected.to_not match %r{<time.*data-time-ago=".*".*>.*</time>}
       end
 
       context 'with given limit' do
@@ -114,16 +116,16 @@ RSpec.describe Rails::Timeago::Helper do
 
           context 'and past timestamp after limit' do
             let(:time) { 5.days.ago }
-            it { is_expected.to match /<time.*data-time-ago=".*".*>.*<\/time>/ }
+            it { is_expected.to match %r{<time.*data-time-ago=".*".*>.*</time>} }
           end
 
           context 'and past timestamp before limit' do
             let(:time) { 8.days.ago }
-            it { is_expected.to_not match /<time.*data-time-ago=".*".*>.*<\/time>/ }
+            it { is_expected.to_not match %r{<time.*data-time-ago=".*".*>.*</time>} }
 
             context 'when forced' do
               let(:kwargs) { super().merge force: true }
-              it { is_expected.to match /<time.*data-time-ago=".*".*>.*<\/time>/ }
+              it { is_expected.to match %r{<time.*data-time-ago=".*".*>.*</time>} }
             end
           end
         end
@@ -133,17 +135,17 @@ RSpec.describe Rails::Timeago::Helper do
 
           context 'and future timestamp after limit' do
             let(:time) { 7.days.from_now }
-            it { is_expected.to_not match /<time.*data-time-ago=".*".*>.*<\/time>/ }
+            it { is_expected.to_not match %r{<time.*data-time-ago=".*".*>.*</time>} }
           end
 
           context 'and future timestamp before limit' do
             let(:time) { 3.days.from_now }
-            it { is_expected.to match /<time.*data-time-ago=".*".*>.*<\/time>/ }
+            it { is_expected.to match %r{<time.*data-time-ago=".*".*>.*</time>} }
           end
 
           context 'and past timestamp' do
             let(:time) { 3.days.ago }
-            it { is_expected.to_not match /<time.*data-time-ago=".*".*>.*<\/time>/ }
+            it { is_expected.to_not match %r{<time.*data-time-ago=".*".*>.*</time>} }
           end
         end
       end
@@ -178,12 +180,12 @@ RSpec.describe Rails::Timeago::Helper do
       let(:kwargs) { {nojs: true} }
 
       it 'has time in words as content' do
-        is_expected.to match /<time.*>%time_ago_in_words%<\/time>/
+        is_expected.to match %r{<time.*>%time_ago_in_words%</time>}
       end
 
       context 'with limit' do
         let(:kwargs) { super().merge limit: 2.days.ago }
-        it { is_expected.to_not match /<time.*data-time-ago=".*".*>.*<\/time>/ }
+        it { is_expected.to_not match %r{<time.*data-time-ago=".*".*>.*</time>} }
         it { is_expected.to include ">#{I18n.l time.to_date}<" }
       end
     end
@@ -192,16 +194,16 @@ RSpec.describe Rails::Timeago::Helper do
       let(:kwargs) { {myattr: 'abc'} }
 
       it 'passes them to #tag_helper' do
-        is_expected.to match /<time.*myattr="abc".*>.*<\/time>/
+        is_expected.to match %r{<time.*myattr="abc".*>.*<\/time>}
       end
     end
   end
 
-  context "#timeago_script_tag" do
+  context '#timeago_script_tag' do
     subject { @stub.timeago_script_tag }
 
-    it "should return a javascript snippet to set jQuery timeago locale" do
-      I18n.locale = "en"
+    it 'should return a javascript snippet to set jQuery timeago locale' do
+      I18n.locale = 'en'
       is_expected.to eq '<script>jQuery.timeago.settings.lang="en";</script>'
     end
   end
